@@ -1,29 +1,16 @@
 import ctypes
-import time
 import tkinter as tk
 import tkinter.ttk as ttk
-from ctypes import windll, POINTER, Structure, c_bool, sizeof, windll, pointer, c_int, c_char, c_long, c_ulong
-from ctypes.wintypes import DWORD, HWND, ULONG, COLORREF
+from ctypes import POINTER, Structure, windll
+from ctypes.wintypes import DWORD, ULONG
 
 from enum import Enum
-from typing import Literal
 
-from tkdev4.devplyer import set_auto_install_plyer, install_plyer, DevNotification, DevEmail
-from tkdev4.devicon import Icon_Empty, Icon_Folder, Icon_Info, Icon_Error, Icon_Warring, Icon_Question, Icon_Questhead, \
-    Icon_Hourglass, Icon_QuickFish, Icon_TkinterDev
-from tkdev4.devresize import DevResize
-from tkdev4.devcore import DevAction, DevSysTray
-from tkdev4.devdraw import DrawButton
-from tkdev4.devtcl import (DevTray, WM_EVENT, download_winico,
-                           WM_RBUTTONDOWN, WM_RBUTTONUP, WM_RBUTTONDBLCLK,
-                           WM_LBUTTONDOWN, WM_LBUTTONUP, WM_LBUTTONDBLCLK,
-                           WM_MBUTTONDOWN, WM_MBUTTONUP, WM_MBUTTONDBLCLK,
-                           WM_MOUSEMOVE,
-                           ICON_APPLICATION, ICON_ASTERISK, ICON_INFORMATION,
-                           ICON_EXCLAMATION, ICON_WINLOGO, ICON_HAND,
-                           ICON_ERROR, ICON_WARNING, ICON_QUESTION,
-                           ICON_MODE_ICON, ICON_MODE_LOAD, ICON_MODE_NONE)
-import warnings
+from src.tkdev4.devplyer import set_auto_install_plyer, install_plyer, DevNotification, DevEmail
+from src.tkdev4.devicon import Icon_Empty, Icon_Folder, Icon_TkinterDev
+from src.tkdev4.devresize import DevResize
+from src.tkdev4.devcore import DevAction
+from src.tkdev4.devtcl import (DevTray, ICON_APPLICATION, ICON_MODE_LOAD)
 
 try:
     from deprecated.sphinx import deprecated
@@ -106,7 +93,6 @@ def Package(File, Ofter="-w", StartMenu: bool = True):
     except:
         Install("pyinstaller")
     import sys
-    import os
     import os.path
 
     os.system(os.path.split(sys.executable)[0] + f"\\Scripts\\pyinstaller.exe {Ofter} {File}")
@@ -1105,24 +1091,6 @@ class DevStatusBar(tk.Frame):
         self.pack(fill=tk.X, side=tk.BOTTOM)
 
 
-class DevToast(tk.Toplevel):
-    def __init__(self, master: tk.Tk = None,
-                 title: str = "Title", message: str = "Message", height: int = 80):
-        super(DevToast, self).__init__(master=master)
-        self.overrideredirect(True)
-        self.title = tk.Label(self, text=title, justify=tk.LEFT, anchor=tk.W)
-        self.title.pack(side=tk.TOP, fill=tk.X)
-        self.message = tk.Label(self, text=message, justify=tk.LEFT, anchor=tk.W)
-        self.message.pack(side=tk.TOP, fill=tk.X)
-        self.height = height
-        self.withdraw()
-
-    def show_toast(self):
-        window_pos_bottom_right(self)
-        self.deiconify()
-        self.after(5000, self.withdraw)
-
-
 class DevToolbox(tk.Toplevel):
     def __init__(self, master: tk.Tk, title: str = "ToolBox"):
         """
@@ -1185,26 +1153,22 @@ class DevToolbox(tk.Toplevel):
         """
         内置函数，用于设置云母特效明亮主题
         """
-        from tkdev import window_mica_light
-        window_mica_light(self.master)
+        DevManage(self.master).use_mica_mode_light()
         self.master.configure(background="#ffffff")
 
     def mica_dark(self):
         """
         内置函数，用于设置云母特效暗黑主题
         """
-        from tkdev import window_mica_dark
-        window_mica_dark(self.master)
+        DevManage(self.master).use_mica_mode_dark()
         self.master.configure(background="#000000")
 
     def acrylic_light(self):
-        from tkdev import window_acrylic
-        window_acrylic(self.master, False)
+        DevManage(self.master).use_acrylic_mode_light()
         self.master.configure(background="#ffffff")
 
     def acrylic_dark(self):
-        from tkdev import window_acrylic
-        window_acrylic(self.master, True)
+        DevManage(self.master).use_acrylic_mode_dark()
         self.master.configure(background="#000000")
 
     def show(self):
@@ -1277,78 +1241,11 @@ class DevWindow(tk.Tk):
         快捷使用窗口，内置多种功能，快速使用
         """
         super(DevWindow, self).__init__()
-        from sys import getwindowsversion
         self.title(title)
         self.geometry("630x300")
         self.iconbitmap(Icon_Empty)
         self.configure(background="#ffffff")
 
-    def wm_screenshot(self, image="Image.png"):
-        """
-        截取窗口
-        """
-        window_screenshot(self, image)
-
-    screenshot = wm_screenshot
-
-    def wm_acrylic(self, mode: Literal["auto", "light", "dark"] = Auto,
-                   mica: bool = False, acrylic: bool = False, hexColor: bool = False):
-        """
-        设置窗口材质为亚克力，
-
-        :param mode: 为主题默认是自动
-        :param mica: 启用mica
-        """
-        if mica:
-            self.mica(mode)
-
-        if mode == "auto":
-            if darkdetect.isLight():
-                window_acrylic(self, dark=False, acrylic=acrylic, hexColor=hexColor)
-                self.configure(background="#eff4f9")
-            if darkdetect.isDark():
-                window_acrylic(self, dark=True, acrylic=acrylic, hexColor=hexColor)
-                self.configure(background="#000000")
-        elif mode == "light":
-            window_acrylic(self, dark=False, acrylic=acrylic, hexColor=hexColor)
-            self.configure(background="#eff4f9")
-        elif mode == "dark":
-            window_acrylic(self, dark=True, acrylic=acrylic, hexColor=hexColor)
-            self.configure(background="#000000")
-        self.update()
-
-    acrylic = wm_acrylic
-
-    def wm_mica(self, mode: Literal["auto", "light", "dark"] = Auto, all: bool = False):
-        """
-        设置窗口材质为云母
-
-        :param mode: 为主题默认是自动
-        :param all: 选择是否隐藏整个窗口。
-        """
-        import platform
-        if platform.system() == "Windows":
-            if all:
-                self.configure(background=self.cget("background"))
-                self.attributes("-transparent", self.cget("background"))
-                self.update()
-            if mode == "auto":
-                if darkdetect.isLight():
-                    window_mica_light(self)
-                    self.configure(background="#d3d3d3")
-                if darkdetect.isDark():
-                    window_mica_dark(self)
-                    self.configure(background="#000000")
-            elif mode == "light":
-                window_mica_light(self)
-                self.configure(background="#d3d3d3")
-            elif mode == "dark":
-                window_mica_dark(self)
-                self.configure(background="#000000")
-        self.update()
-
-    mica = wm_mica
-
     def wm_remove_titlebar(self):
         """
         移除标题栏与边框，保留着任务栏
@@ -1365,14 +1262,6 @@ class DevWindow(tk.Tk):
 
     remove_titlebar_none_border = wm_remove_titlebar_none_border
 
-    def wm_run(self):
-        """
-        运行窗口，没什么作用
-        """
-        self.mainloop()
-
-    run = wm_run
-
     def wm_statusbar(self, statusBar: tk.Widget = None):
         """
         设置状态栏，
@@ -1463,15 +1352,6 @@ class DevWindow(tk.Tk):
         self.titlebar(titlebar)
         return titlebar
 
-    def seed_notification(self, title: str = "", message: str = "", app_name: str = "Python", app_icon="",
-                          time_out: int = 0):
-        def show():
-            Notification = DevNotification(title=title, message=message, app_name=app_name, app_icon=app_icon,
-                                           timeout=time_out)
-            Notification.show()
-
-        self.after(1000, show)
-
     def dpi(self):
         """
         设置dpi高清晰度
